SmartDateApi class
DO NOT EDIT THIS FILE. TO ADJUST THIS CLASS, USE SmartDateApiMixin
The final API is constructed by:
- taking the
SmartDateApiBaseclass - applying a mixin SmartDateApiMixin ] (which allows us to inject other convenience functions) The mixin lives outside of the code generator, so it's used to do any manual tweaking
- Applying the
SignalingApiMixin, so events automatically propagate
- Inheritance
-
- Object
- Repository<
ISmartDate> - SunnyApi<
ISmartDate> - SmartDateApi
- Implemented types
- Mixed-in types
-
- SignalingApiMixin<
ISmartDate>
- SignalingApiMixin<
Constructors
- SmartDateApi(ApiClient apiClient, ApiRegistry apis)
Properties
Methods
-
clone(
ISmartDate source) → ISmartDate -
Copies values from one entity into another. This clone operation is important because it allows
inherited
-
create(
ISmartDate body) → Future< ISmartDate> -
inherited
-
delete(
String id) → Future< DeleteResponse> -
inherited
-
initialize(
ISmartDate entity) → ISmartDate -
inherited
-
instantiate(
[dynamic json]) → ISmartDate -
inherited
-
keyToId(
MKey? key) → String? -
inherited
-
list(
{double? limit, double? offset}) → Future< MModelList< ISmartDate> > -
inherited
-
load(
String id) → Future< ISmartDate> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseSmartDate(
IParseSmartDateRequest parseSmartDateRequest) → Future< ISmartDateResults> -
override
-
takeFrom(
ISmartDate source, ISmartDate target) → void -
Copies all data from
sourceintotarget. Used when you want to maintain a reference totarget, but want to inject new values fromsourceinherited -
toString(
) → String -
A string representation of this object.
inherited
-
update(
String id, ISmartDate body) → Future< ChangeResult> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited