RelativeDate class

Inheritance
Implemented types

Constructors

RelativeDate(Map<String, dynamic> wrapped, {MSchemaRef mtype = RelativeDateRef, bool update = true})

Properties

amount num?
Property getter and setter for amount:
getter/setter pairoverride
diffHashCode int
no setterinherited
diffKey → dynamic
For Diffable
no setterinherited
diffSource → dynamic
For Diffable
no setterinherited
eventName String?
Property getter and setter for eventName:
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
ignoredPaths Set<JsonPath>
no setterinherited
mfields Set<String>
no setteroverride
mkey → MKey?
no setterinherited
mkeyOrNull → MKey?
no setterinherited
mtype → MSchemaRef
no setterinherited
recordKey → RecordKey?
no setterinherited
relativeDate IRelativeDate?
Property getter and setter for relativeDate:
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seek ISeekDirection?
Property getter and setter for seek:
getter/setter pairoverride
seekUnit String?
Property getter and setter for seekUnit:
getter/setter pairoverride
timeUnit String?
Property getter and setter for timeUnit:
getter/setter pairoverride
wrapped Map<String, dynamic>
finalinherited

Methods

call<T>(dynamic key) → T?
inherited
clone() RelativeDate
override
diffEquals(dynamic other) bool
inherited
diffIdentical(dynamic other) bool
inherited
get(String name) → dynamic
inherited
getByPath<T>(JsonPath path) → T
inherited
has(String fieldName) bool
inherited
jpath<T>(JsonPath<T> path, [T? value]) → T?
inherited
modified() → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prune(Set<String> fields) → void
inherited
setByPath<T>(JsonPath<T> path, T? value) → dynamic
inherited
sync([Set<String>? fields]) → void
There are some weird cases where collections aren't synced properly with the underlying json. This will overwrite the json with the latest value of the variable.
inherited
takeFrom(dynamic source) → void
override
takeFromMap(Map<String, dynamic>? from, {bool copyEntries = true}) → void
Used for meta-forms in setting deep properties
override
toJson() → dynamic
override
toMap() Map<String, dynamic>
For RouteParams - move at some point?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
override
operator []=(String key, dynamic value) → void
override

Static Methods

fromJson(dynamic wrapped) RelativeDate
override
of({required ISeekDirection? seek, required String? seekUnit, required num? amount, String? timeUnit, String? eventName, IRelativeDate? relativeDate}) RelativeDate